import bpy
from enums import ObjectTypeEnum

from pyedm_platform_selector import pyedm

from logger import log
from mesh_builder import get_mesh
from objects_custom_props import get_edm_props

## check if object is segment
def is_segment(object: bpy.types.Object) -> bool:
    edm_props = get_edm_props(object)
    if object.type in (ObjectTypeEnum.MESH, ObjectTypeEnum.CURVE, ObjectTypeEnum.CURVES) and edm_props.SPECIAL_TYPE in ('COLLISION_LINE'):
        return True
    return False

## from Blender-type object create and return segments that can be exported to EDM.
def create_segments_node(o: bpy.types.Object, name: str, control_node: pyedm.Node) -> pyedm.SegmentsNode:
    bpy_mesh = get_mesh(o)
    segment_node = pyedm.SegmentsNode(name)
    
    #parse coordinates
    vertices = []
    for vertex in bpy_mesh.vertices:
        pos = [vertex.co[0], vertex.co[1], vertex.co[2]]
        vertices.append(pos)

    #prepare edges
    edges = []
    for edge in bpy_mesh.edges:
        p1 = vertices[edge.vertices[0]]
        p2 = vertices[edge.vertices[1]]
        edges.append((p1, p2))
    
    segment_node.set(edges)
    segment_node.setControlNode(control_node)
    
    return segment_node


